@@ -284,8 +284,8 @@ class BaremetalMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             to the update_port call.
         """
         port = context.current
-        if (port[portbindings.VNIC_TYPE] in self.supported_vnic_types and
-                port[portbindings.VIF_TYPE] == self.vif_type):
+        if (port[portbindings.VNIC_TYPE] in self.supported_vnic_types
+                and port[portbindings.VIF_TYPE] == self.vif_type):
             provisioning_blocks.provisioning_complete(
                 context._plugin_context, port['id'], resources.PORT,
                 BAREMETAL_DRV_ENTITY)
@@ -326,7 +326,7 @@ class BaremetalMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
         :returns: True iff segment has been bound for agent
 
         Neutron segments api-ref:
-          https://developer.openstack.org/api-ref/network/v2/#segments
+          https://docs.openstack.org/api-ref/network/v2/#segments
 
         Example segment dictionary: {'segmentation_id': 'segmentation_id',
                                      'network_type': 'network_type',
